/*
 * doc_extern_tools.h
 * Copyright (C) 2012 Olivier Sessink
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __DOC_EXTERN_TOOLS_H_
#define __DOC_EXTERN_TOOLS_H_

void lorem_ipsum_dialog(Tbfwin *bfwin);
void jsbeautify_dialog(Tbfwin *bfwin);

#ifdef WIN32
gboolean check_python();
#endif

#endif /*__DOC_EXTERN_TOOLS_H_*/
